@@ -565,7 +565,7 @@ sub _as_text {
   return $out;
 }
 
-sub as_block	{ Encode::encode_utf8(_as_text(shift, WARC::CRLF)) }
+sub as_block	{ Encode::encode('UTF-8', _as_text(shift, WARC::CRLF)) }
 sub as_string	{ _as_text(shift, "\n") }
 
 =item $f-E<gt>set_readonly
